export interface ExcaliDrawPrimitiveProps {
    readonly type?: string;
    readonly x?: number;
    readonly y?: number;
    readonly width?: number;
    readonly height?: number;
    readonly groupIds?: string[];
}
export interface BoundElement {
    readonly id: string;
    readonly type: string;
}
export declare abstract class ExcaliDrawPrimitive {
    type: string;
    id: string;
    x: number;
    y: number;
    width: number;
    height: number;
    seed: number;
    isDeleted: boolean;
    frameId: any;
    angle: number;
    boundElements: BoundElement[];
    updated: number;
    link: any;
    locked: boolean;
    version: number;
    versionNonce: number;
    groupIds: string[];
    constructor(args: ExcaliDrawPrimitiveProps);
    addBoundElement(element: ExcaliDrawPrimitive): void;
}
export interface Roundness {
    readonly type: number;
}
export declare enum StrokeStyle {
    SOLID = "solid",
    DASHED = "dashed",
    DOTTED = "dotted"
}
export declare enum ArrowHead {
    TRIANGLE = "triangle",
    ARROW = "arrow"
}
export declare enum FillStyle {
    HACHURE = "hachure",
    SOLID = "solid",
    CROSSHATCH = "cross-hatch",
    DOTS = "dots"
}
export declare enum TextAlign {
    CENTER = "center",
    LEFT = "left",
    RIGHT = "right"
}
export declare enum VerticalAlign {
    TOP = "top"
}
export interface Binding {
    readonly elementId: string;
    readonly focus: number;
    readonly gap: number;
}
export interface DrawnObjectProps extends ExcaliDrawPrimitiveProps {
    readonly strokeWidth?: number;
    readonly strokeStyle?: StrokeStyle;
    readonly strokeColor?: string;
    readonly fillStyle?: FillStyle;
    readonly roughness?: number;
    readonly opacity?: number;
    readonly backgroundColor?: string;
    readonly roundness?: any;
}
export declare abstract class DrawnObject extends ExcaliDrawPrimitive {
    readonly strokeColor: string;
    readonly strokeWidth: number;
    readonly strokeStyle: StrokeStyle;
    readonly fillStyle: FillStyle;
    readonly roughness: number;
    readonly opacity: number;
    readonly backgroundColor: string;
    readonly roundness: any;
    constructor(args: DrawnObjectProps);
}
export interface LineLikeProps extends DrawnObjectProps {
    readonly startBinding?: any;
    readonly endBinding?: any;
    readonly lastCommittedPoint?: any;
    readonly startArrowhead?: any;
    readonly endArrowhead?: any;
}
export declare abstract class LineLike extends DrawnObject {
    readonly startBinding: any;
    readonly endBinding: any;
    readonly lastCommittedPoint: any;
    readonly startArrowhead: any;
    readonly endArrowhead: any;
    constructor(args: LineLikeProps);
}
export interface LineProps extends LineLikeProps {
    readonly points?: number[][];
}
export declare class Line extends LineLike {
    points: number[][];
    constructor(args: LineProps);
}
export interface RectangleProps extends LineLikeProps {
}
export declare class Rectangle extends DrawnObject {
    constructor(args: LineLikeProps);
}
export interface EllipseProps extends LineLikeProps {
}
export declare class Ellipse extends DrawnObject {
    constructor(args: EllipseProps);
}
export interface ArrowProps extends LineProps {
}
export declare class Arrow extends Line {
    constructor(args: ArrowProps);
}
export interface TextProps extends DrawnObjectProps {
    readonly fontFamily?: number;
    readonly fontSize?: number;
    readonly textAlign?: string;
    readonly verticalAlign?: string;
    readonly containerId?: any;
    readonly originalText?: string;
    readonly text: string;
    readonly lineHeight?: number;
    readonly baseline?: number;
}
export declare class Text extends DrawnObject {
    fontFamily: number;
    fontSize: number;
    textAlign: string;
    verticalAlign: string;
    containerId: any;
    originalText: string;
    text: string;
    lineHeight: number;
    baseline: number;
    constructor(args: TextProps);
}
